@@ -67,36 +67,46 @@ class admin():
                 await ctx.send(f"{member} is not banned.", delete_after=5)
 class curse():
     async def add_banned_word(ctx, word, dir):
-        try:
-            os.chdir(dir)
-            word = word.lower()
-            guildid = str(ctx.guild.id)
-            db = await aiosqlite.connect("curse.db")
-            await db.execute(f"""CREATE TABLE if NOT EXISTS curses(
-            curse TEXT PRIMARY KEY,
-            guild TEXT
-            )""")
-            await db.commit()
-            if "," in word:
-                word = word.replace(" ", "")
-                word = word.split(",")
-                words = []
-                for x in word:
-                    words.append(x)
-                    if words.count(x) > 1:
-                        await ctx.send("Words cannot be added twice.", delete_after=5)
-                        return
+        arg = word
+        os.chdir(dir)
+        word = word.lower()
+        guildid = str(ctx.guild.id)
+        db = await aiosqlite.connect("curse.db")
+        await db.execute(f"""CREATE TABLE if NOT EXISTS curses(
+        curse TEXT,
+        guild TEXT
+        )""")
+        await db.commit()
+        async with db.execute("SELECT curse FROM curses WHERE guild = ?", (guildid,)) as cursor:
+            async for entry in cursor:
+                curse = entry[0]
+                words = word.replace(" ", "")
+                words = words.split(",")
                 for x in words:
-                    await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (x,guildid))
-                await db.commit()
-                word = ", ".join(word)
-            else:
-                await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (word,guildid))
-                await db.commit()
-            await db.close()
-        except:
-            await ctx.send(f"{word} is already in the list.", delete_after=5)
-            await db.close()
+                    if x == curse:
+                        if "," in arg:
+                            msg = f"One of those words are already in the list."
+                        else:
+                            msg = f"{word} is already in the list."
+                        await ctx.send(msg, delete_after=5)
+                        return
+        await db.close()
+        if "," in word:
+            word = word.replace(" ", "")
+            word = word.split(",")
+            words = []
+            for x in word:
+                words.append(x)
+                if words.count(x) > 1:
+                    await ctx.send("Words cannot be added twice.", delete_after=5)
+                    return
+            for x in words:
+                await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (x,guildid))
+            await db.commit()
+        else:
+            await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (word,guildid))
+            await db.commit()
+        await db.close()
     async def remove_banned_word(ctx, word, dir):
             db = await aiosqlite.connect("curse.db")
             guildid = str(ctx.guild.id)
@@ -203,6 +213,8 @@ class curse():
         try:
             db = await aiosqlite.connect("curse.db")
             await db.execute("DELETE FROM curses WHERE guild = ?", (guildid,))
+            await db.commit()
+            await ctx.send("Cleraed all curses from this server", delete_after=7)
             await db.close()
         except:
             await ctx.send("There is not a curse list for this guild. Create one by doing !addword followed by a list of words or a single word.", delete_after=10)
@@ -519,4 +531,77 @@ class warnings():
                                     await mute_on_join.mute_add(ctx, member, dir)
                             else:
                                 await member.add_roles(add_role)
-                                await mute_on_join.mute_add(ctx, member, dir)
\ No newline at end of file
+                                await mute_on_join.mute_add(ctx, member, dir)
+class rr():
+    async def command(ctx, emoji, dir, role, *args, title, description, **kwargs):
+        os.chdir(dir)
+        db = await aiosqlite.connect("rr.db")
+        await db.execute("""CREATE TABLE IF NOT EXISTS rr(
+        msg_id TEXT,
+        emoji UNICODE,
+        role TEXT,
+        guild TEXT
+        )""")
+        await db.commit()
+        embed = discord.Embed(title = title, color = 0x0000FF, description = description)
+        msg = await ctx.send(embed=embed)
+        if "," in emoji:
+            emoji = emoji.replace(" ", "")
+            emoji_list = emoji.split(",")
+            role = role.replace(" ", "")
+            role_list = role.split(",")
+            number = 0
+            for x in emoji_list:
+                role = role_list[number]
+                role = role.replace("<", "")
+                role = role.replace(">", "")
+                role = role.replace("@", "")
+                role = role.replace("&", "")
+                number += 1
+                await msg.add_reaction(x)
+                await db.execute("INSERT INTO rr (msg_id,emoji,role,guild) VALUES (?,?,?,?)", (str(msg.id),x,str(role),str(ctx.guild.id)))
+            await db.commit()
+            await db.close()
+        else:
+            await msg.add_reaction(emoji)
+            role = role.replace("<", "")
+            role = role.replace(">", "")
+            role = role.replace("@", "")
+            role = role.replace("&", "")
+            await db.execute("INSERT INTO rr (msg_id,emoji,role,guild) VALUES (?,?,?,?)", (str(msg.id),emoji,str(role),str(ctx.guild.id)))
+            await db.commit()
+            await db.close()
+
+    async def add(payload, dir, client):
+        os.chdir(dir)
+        guild = client.get_guild(payload.guild_id)
+        db = await aiosqlite.connect("rr.db")
+        async with db.execute("SELECT emoji,role FROM rr WHERE guild = ? and msg_id = ?", (str(guild.id),str(payload.message_id))) as cursor:
+            async for entry in cursor:
+                emoji,role = entry
+                role = guild.get_role(int(role))
+                if str(payload.emoji) == emoji:
+                    await payload.member.add_roles(role)
+        await db.close()
+
+    async def remove(payload, dir, client):
+        os.chdir(dir)
+        guild = client.get_guild(payload.guild_id)
+        member = guild.get_member(payload.user_id)
+        db = await aiosqlite.connect("rr.db")
+        async with db.execute("SELECT emoji,role FROM rr WHERE guild = ? and msg_id = ?", (str(guild.id),str(payload.message_id))) as cursor:
+            async for entry in cursor:
+                emoji,role = entry
+                role = guild.get_role(int(role))
+                if str(payload.emoji) == emoji:
+                    await member.remove_roles(role)
+        await db.close()
+
+    async def clear(ctx, dir):
+        os.chdir(dir)
+        guild = str(ctx.guild.id)
+        db = await aiosqlite.connect("rr.db")
+        await db.execute("DELETE FROM rr WHERE guild = ?", (guild,))
+        await db.commit()
+        await db.close()
+        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
\ No newline at end of file
